@@ -1,11 +1,10 @@
 use strict;
 use warnings;
 
-use lib qw(../../..);
-
 =head1 NAME
 
-Algorithm::Evolutionary::Op::ArithCrossover - Arithmetic crossover operator; performs the average of the n parents crossed
+    Algorithm::Evolutionary::Op::ArithCrossover - Arithmetic crossover operator; performs the average of
+                     the n parents crossed
                  
 
 =head1 SYNOPSIS
@@ -35,18 +34,18 @@ Crossover operator for a vector-rep individual
 
 package Algorithm::Evolutionary::Op::ArithCrossover;
 
-our $VERSION =   sprintf "%d.%03d", q$Revision: 3.1 $ =~ /(\d+)\.(\d+)/g; # Hack for avoiding version mismatch
+our ($VERSION) = ( '$Revision: 1.1.1.1 $ ' =~ /(\d+\.\d+)/ );
 
 use Carp;
-use Clone qw(clone);
 
-use base 'Algorithm::Evolutionary::Op::Base';
+use Algorithm::Evolutionary::Op::Base;
+our @ISA = ('Algorithm::Evolutionary::Op::Base');
 
 #Class-wide constants
 our $APPLIESTO =  'Algorithm::Evolutionary::Individual::Vector';
 our $ARITY = 2;
 
-=head2 create()
+=head2 create
 
 Creates the operator, but is more or less empty. Does not have instance variables
 
@@ -59,20 +58,19 @@ sub create {
   return $self;
 }
 
-=head2 apply( $chromosome_1, $chromosome_2 )
+=head2 apply
 
 Applies xover operator to a "Chromosome", a vector of stuff,
 really. Can be applied only to I<victims> with the C<_array> instance
 variable; but it checks before application that both operands are of
-type L<Algorithm::Evolutionary::Individual::Vector|Algorithm::Evolutionary::Individual::Vector>. 
-Returns the resulting chromosome
+type L<Algorithm::Evolutionary::Individual::Vector|Algorithm::Evolutionary::Individual::Vector>.
 
 =cut
 
 sub  apply ($$;$){
   my $self = shift;
   my $arg = shift || croak "No victim here!";
-  my $victim = clone($arg);
+  my $victim = $arg->clone();
   my $victim2 = shift || croak "No victim here!";
   croak "Incorrect type ".(ref $victim) if !$self->check($victim);
   croak "Incorrect type ".(ref $victim2) if !$self->check($victim2);
@@ -90,10 +88,10 @@ sub  apply ($$;$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2011/02/14 06:55:36 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/ArithCrossover.pm,v 3.1 2011/02/14 06:55:36 jmerelo Exp $ 
+  CVS Info: $Date: 2008/02/12 17:49:39 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/ArithCrossover.pm,v 1.1.1.1 2008/02/12 17:49:39 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.1 $
+  $Revision: 1.1.1.1 $
   $Name $
 
 =cut
